.. image:: https://travis-ci.org/timcera/swmmtoolbox.svg?branch=master
    :target: https://travis-ci.org/timcera/swmmtoolbox
    :height: 20

.. image:: https://coveralls.io/repos/timcera/swmmtoolbox/badge.png?branch=master
    :target: https://coveralls.io/r/timcera/swmmtoolbox?branch=master
    :height: 20

.. image:: https://img.shields.io/pypi/v/swmmtoolbox.svg
    :alt: Latest release
    :target: https://pypi.python.org/pypi/swmmtoolbox

.. image:: http://img.shields.io/badge/license-BSD-lightgrey.svg
    :alt: BSD-3 clause license
    :target: https://pypi.python.org/pypi/swmmtoolbox/

.. image:: http://img.shields.io/pypi/dd/swmmtoolbox.svg
    :alt: swmmtoolbox downloads
    :target: https://pypi.python.org/pypi/swmmtoolbox/
